@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 3.8.1.  */
+/* A Bison parser, made by GNU Bison 3.8.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
@@ -46,10 +46,10 @@
    USER NAME SPACE" below.  */
 
 /* Identify Bison output, and Bison version.  */
-#define YYBISON 30801
+#define YYBISON 30802
 
 /* Bison version string.  */
-#define YYBISON_VERSION "3.8.1"
+#define YYBISON_VERSION "3.8.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -294,7 +294,7 @@ Msc MscParse(FILE *in)
 
 
 
-#line 298 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 298 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -1446,7 +1446,7 @@ yyreduce:
     *(Msc *)yyparse_result = (yyval.msc);
 
 }
-#line 1450 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1450 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 3: /* msc: TOK_MSC TOK_OCBRACKET entitylist TOK_SEMICOLON arclist TOK_SEMICOLON TOK_CCBRACKET  */
@@ -1456,7 +1456,7 @@ yyreduce:
     *(Msc *)yyparse_result = (yyval.msc);
 
 }
-#line 1460 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1460 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 5: /* optlist: optlist TOK_COMMA opt  */
@@ -1464,7 +1464,7 @@ yyreduce:
 {
     (yyval.opt) = MscLinkOpt((yyvsp[-2].opt), (yyvsp[0].opt));
 }
-#line 1468 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1468 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 6: /* opt: optval TOK_EQUAL string  */
@@ -1472,7 +1472,7 @@ yyreduce:
 {
     (yyval.opt) = MscAllocOpt((yyvsp[-2].optType), (yyvsp[0].string));
 }
-#line 1476 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1476 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 11: /* entitylist: entity  */
@@ -1480,7 +1480,7 @@ yyreduce:
 {
     (yyval.entitylist) = MscLinkEntity(NULL, (yyvsp[0].entity));   /* Create new list */
 }
-#line 1484 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1484 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 12: /* entitylist: entitylist TOK_COMMA entity  */
@@ -1488,7 +1488,7 @@ yyreduce:
 {
     (yyval.entitylist) = MscLinkEntity((yyvsp[-2].entitylist), (yyvsp[0].entity));     /* Add to existing list */
 }
-#line 1492 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1492 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 13: /* entity: string  */
@@ -1496,7 +1496,7 @@ yyreduce:
 {
     (yyval.entity) = MscAllocEntity((yyvsp[0].string));
 }
-#line 1500 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1500 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 14: /* entity: entity TOK_OSBRACKET attrlist TOK_CSBRACKET  */
@@ -1504,7 +1504,7 @@ yyreduce:
 {
     MscEntityLinkAttrib((yyvsp[-3].entity), (yyvsp[-1].attrib));
 }
-#line 1508 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1508 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 15: /* arclist: arc  */
@@ -1512,7 +1512,7 @@ yyreduce:
 {
     (yyval.arclist) = MscLinkArc(NULL, (yyvsp[0].arc));      /* Create new list */
 }
-#line 1516 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1516 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 16: /* arclist: arclist TOK_SEMICOLON arc  */
@@ -1520,7 +1520,7 @@ yyreduce:
 {
     (yyval.arclist) = MscLinkArc((yyvsp[-2].arclist), (yyvsp[0].arc));     /* Add to existing list */
 }
-#line 1524 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1524 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 17: /* arclist: arclist TOK_COMMA arc  */
@@ -1529,7 +1529,7 @@ yyreduce:
     /* Add a special 'parallel' arc */
     (yyval.arclist) = MscLinkArc(MscLinkArc((yyvsp[-2].arclist), MscAllocArc(NULL, NULL, MSC_ARC_PARALLEL, lex_getlinenum())), (yyvsp[0].arc));
 }
-#line 1533 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1533 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 18: /* arc: arcrel TOK_OSBRACKET attrlist TOK_CSBRACKET  */
@@ -1537,7 +1537,7 @@ yyreduce:
 {
     MscArcLinkAttrib((yyvsp[-3].arc), (yyvsp[-1].attrib));
 }
-#line 1541 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1541 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 20: /* arcrel: TOK_SPECIAL_ARC  */
@@ -1545,7 +1545,7 @@ yyreduce:
 {
     (yyval.arc) = MscAllocArc(NULL, NULL, (yyvsp[0].arctype), lex_getlinenum());
 }
-#line 1549 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1549 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 21: /* arcrel: string relation_box string  */
@@ -1553,7 +1553,7 @@ yyreduce:
 {
     (yyval.arc) = MscAllocArc((yyvsp[-2].string), (yyvsp[0].string), (yyvsp[-1].arctype), lex_getlinenum());
 }
-#line 1557 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1557 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 22: /* arcrel: string relation_bi string  */
@@ -1563,7 +1563,7 @@ yyreduce:
     MscArcLinkAttrib(arc, MscAllocAttrib(MSC_ATTR_BI_ARROWS, strdup_s("true")));
     (yyval.arc) = arc;
 }
-#line 1567 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1567 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 23: /* arcrel: string relation_to string  */
@@ -1571,7 +1571,7 @@ yyreduce:
 {
     (yyval.arc) = MscAllocArc((yyvsp[-2].string), (yyvsp[0].string), (yyvsp[-1].arctype), lex_getlinenum());
 }
-#line 1575 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1575 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 24: /* arcrel: string relation_line string  */
@@ -1581,7 +1581,7 @@ yyreduce:
     MscArcLinkAttrib(arc, MscAllocAttrib(MSC_ATTR_NO_ARROWS, strdup_s("true")));
     (yyval.arc) = arc;
 }
-#line 1585 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1585 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 25: /* arcrel: string relation_from string  */
@@ -1589,7 +1589,7 @@ yyreduce:
 {
     (yyval.arc) = MscAllocArc((yyvsp[0].string), (yyvsp[-2].string), (yyvsp[-1].arctype), lex_getlinenum());
 }
-#line 1593 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1593 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 26: /* arcrel: string relation_to TOK_ASTERISK  */
@@ -1597,7 +1597,7 @@ yyreduce:
 {
     (yyval.arc) = MscAllocArc((yyvsp[-2].string), strdup_s("*"), (yyvsp[-1].arctype), lex_getlinenum());
 }
-#line 1601 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1601 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 27: /* arcrel: TOK_ASTERISK relation_from string  */
@@ -1605,7 +1605,7 @@ yyreduce:
 {
     (yyval.arc) = MscAllocArc((yyvsp[0].string), strdup_s("*"), (yyvsp[-1].arctype), lex_getlinenum());
 }
-#line 1609 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1609 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 54: /* attrlist: attrlist TOK_COMMA attr  */
@@ -1613,7 +1613,7 @@ yyreduce:
 {
     (yyval.attrib) = MscLinkAttrib((yyvsp[-2].attrib), (yyvsp[0].attrib));
 }
-#line 1617 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1617 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 55: /* attr: attrval TOK_EQUAL string  */
@@ -1621,7 +1621,7 @@ yyreduce:
 {
     (yyval.attrib) = MscAllocAttrib((yyvsp[-2].attribType), (yyvsp[0].string));
 }
-#line 1625 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1625 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 67: /* string: TOK_QSTRING  */
@@ -1629,7 +1629,7 @@ yyreduce:
 {
     (yyval.string) = removeEscapes((yyvsp[0].string));
 }
-#line 1633 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1633 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
   case 68: /* string: TOK_STRING  */
@@ -1637,11 +1637,11 @@ yyreduce:
 {
     (yyval.string) = (yyvsp[0].string);
 }
-#line 1641 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1641 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
     break;
 
 
-#line 1645 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/mscgen_language.cpp"
+#line 1645 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.4-1.x86_64/build/generated_src/mscgen_language.cpp"
 
       default: break;
     }
